# Docker image for Easya (Dolibarr)

Docker image for Easya with auto installer on first boot and database migrations on upgrade.

## Supported tags

- `latest`
- `<MAJOR>` like `2024`
- `<VERSION>` like `2024.0.25.09`
- `<FLAVOR>` like `frankenphp`
- `<MAJOR/VERSION>-<FLAVOR>` like `2024-frankenphp` or `2024.0.25.09-apache`

## Flavors

### [FrankenPHP](https://frankenphp.dev/) (`frankenphp`)
> Version : `2024`

Optimized webserver for PHP.

### Apache (`apache`)
> Version : `2024` `2022`, `2020`

Less optimize but works with older versions.

### PHP FPM Alpine (`fpm-alpine`) **DEPRECATED**
> Version : `2024`, `2022`

This use a FPM server on Alpine Linux and need a web server to server static files like Nignx.

## Supported architectures

- Linux x86-64 (`amd64`)

## What is [Easya](https://github.com/Easya-Solutions/dolibarr) ?

Easya is a fork of Dolibarr made by Open-DSI.

Dolibarr ERP & CRM is a modern software package to manage your organization's activity (contacts, suppliers, invoices, orders, stocks, agenda, ...).

## How to run this image ?

This image is based on the [official PHP repository](https://registry.hub.docker.com/_/php/).

**Important**: This image don't contains database. So you need to link it with a database container.

Let's use [Docker Compose](https://docs.docker.com/compose/) to integrate it with [MariaDB](https://hub.docker.com/_/mariadb/) (you can also use [MySQL](https://hub.docker.com/_/mysql/) if you prefer).

Create a `docker-compose.yml`, you can use [docker-compose.yml](./examples/frankenphp/docker-compose.yml) as an example.

Then run all services `docker-compose up -d`.
Now, go to http://127.0.0.1:8888 to access to the new Dolibarr installation.

## Upgrading version and migrating DB

The `install.lock` file is located inside the container volume `/var/www/html/documents`.

Remove the `install.lock` file and start an updated version container.
You have to access `/install` on your navigator and launch all missing migrations.

## Volumes

For a typical use :
- `/var/www/html/documents`: Documents (PDF, pictures, etc...)
- `/var/www/html/htdocs/custom` : Additional modules

## Environment variables summary

| Variable                   | Default value                          | Description                                    |
|----------------------------|----------------------------------------|------------------------------------------------|
| DOLI_UNIQUE_ID             |                                        | Dolibarr unique ID                             |
| DOLI_ADMIN_LOGIN           |                                        | Dolibarr admin login (only used on install)    |
| DOLI_ADMIN_PASSWORD        |                                        | Dolibarr admin password (only used on install) |
| DOLI_URL_ROOT              | `http://localhost`                     | Public URL                                     |
| DOLI_WWW                   | `/var/www/html`                        | Root folder                                    |
| DOLI_HTDOCS                | `/var/www/html/htdocs`                 | Root web folder                                |
| DOLI_CUSTOM                | `/custom`                              | Relative path to modules                       |
| DOLI_ROOT_ALT              | `/var/www/html/htdocs/custom`          | Modules folders                                |
| DOLI_DATA                  | `/var/www/html/documents`              | Documents folder                               |
| DOLI_DB_TYPE               | `mysqli`                               | Database type                                  |
| DOLI_DB_HOST               |                                        | Database host                                  |
| DOLI_DB_PORT               | `3306`                                 | Database port                                  |
| DOLI_DB_NAME               |                                        | Database name                                  |
| DOLI_DB_USER               |                                        | Database username                              |
| DOLI_DB_PASSWORD           |                                        | Database password                              |
| DOLI_DB_PREFIX             | `llx_`                                 | Database tables prefix                         |
| DOLI_DB_CHAR_SET           | `utf8`                                 | Database character set                         |
| DOLI_DB_COLLATION          | `utf8_unicode_ci`                      | Database collation                             |
| DOLI_AUTH                  | `dolibarr`                             | Dolibarr auth methods                          |
| DOLI_FORCE_HTTPS           | `0`                                    | Force HTTPS                                    |
| DOLI_PROD                  | `1`                                    | Is production environnement                    |
| DOLI_RESTRICT_OS_COMMANDS  | `mysqldump, mysql, pg_dump, pgrestore` | Allowed OS commands                            |
| DOLI_RESTRICT_IP           | Disabled if empty                      | Allowlist of IP                                |
| DOLI_NO_CSRF_CHECK         | `0`                                    | Disable CSRF check                             |
| DOLI_CRON_ALLOW_CLI        | `0`                                    | Allow command for scheduled jobs               |
| DOLI_LANG                  | `fr_FR`                                | Dolibarr language (only used on install)       |
| DOLI_SKIP_VERSION_CHECK    | `false`                                | Disable the installation and upgrade logic     |
| PHP_MAX_EXECUTION_TIME     | `200`                                  | PHP Max execution time                         |
| PHP_MEMORY_LIMIT           | `512M`                                 | PHP memory limit                               |
| PHP_UPLOAD_LIMIT           | `10M`                                  | PHP upload limit                               |
| PHP_SESSION_GC_MAXLIFETIME | `3600`                                 | PHP max session time                           |
| PHP_SESSION_SAVE_HANDLER   | `files`                                | PHP session handler                            |
| PHP_SESSION_SAVE_PATH      | PHP default to `/tmp`                  | PHP session save path                          |
| TZ                         | `UTC`                                  | System timezone                                |
| PHP_XDEBUG_MODE            | `develop,debug`                        | Xdebug mod (`-dev` only)                       |
| PHP_XDEBUG_PORT            | `9003`                                 | Xdebug host port (`-dev` only)                 |

## Developing
All images have a `<...>-dev` alterative, this disable OPcache and add Xdebug extension.

This used the release candidate version of the code (`_rc`)

You can overwrite the whole code by mouting `/var/www/html` and no other volumes
